#ifndef XRACER_CONFIG_H
#define XRACER_CONFIG_H
@TOP@

/*
 *   Defaults for configuration settings
 */

#undef PACKAGE
#undef VERSION
#undef MAJOR_VERSION
#undef MINOR_VERSION
#undef PATCH_VERSION
#undef VERSION_STRING
#undef HAVE_DL_API
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

@BOTTOM@

#endif /* XRACER_CONFIG_H */
